"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.defaultTypeValue = defaultTypeValue;
exports.defaultFieldValue = defaultFieldValue;
exports.getAlternativeWidget = getAlternativeWidget;
exports.getDefaultFormState = getDefaultFormState;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _componentsWidgetsRadioWidget = require("./components/widgets/RadioWidget");

var _componentsWidgetsRadioWidget2 = _interopRequireDefault(_componentsWidgetsRadioWidget);

var _componentsWidgetsSelectWidget = require("./components/widgets/SelectWidget");

var _componentsWidgetsSelectWidget2 = _interopRequireDefault(_componentsWidgetsSelectWidget);

var _componentsWidgetsTextareaWidget = require("./components/widgets/TextareaWidget");

var _componentsWidgetsTextareaWidget2 = _interopRequireDefault(_componentsWidgetsTextareaWidget);

function defaultTypeValue(type) {
  switch (type) {
    case "array":
      return [];
    case "boolean":
      return false;
    case "date-time":
      return "";
    case "number":
      return 0;
    case "object":
      return {};
    case "string":
      return "";
    default:
      return undefined;
  }
}

function defaultFieldValue(formData, schema) {
  return formData === null ? defaultTypeValue(schema.type) : formData;
}

function getAlternativeWidget(name) {
  switch (name) {
    case "radio":
      return _componentsWidgetsRadioWidget2["default"];
    case "select":
      return _componentsWidgetsSelectWidget2["default"];
    case "textarea":
      return _componentsWidgetsTextareaWidget2["default"];
    default:
      throw new Error("No alternative widget for \"" + name + "\"");
  }
}

function getDefaultFormState(schema) {
  if (typeof schema !== "object") {
    throw new Error("Invalid schema: " + schema);
  }
  if ("default" in schema) {
    return schema["default"];
  }
  if (schema.type === "object") {
    return Object.keys(schema.properties).reduce(function (acc, key) {
      acc[key] = getDefaultFormState(schema.properties[key]);
      return acc;
    }, {});
  }
  return defaultTypeValue(schema.type);
}